@@ -152,6 +152,9 @@ FAILEDOPERATION_REQUESTVENDORTIMEOUT = 'FailedOperation.RequestVendorTimeout'
 # 该资源不可访问。
 FAILEDOPERATION_RESOURCECANNOTACCESS = 'FailedOperation.ResourceCanNotAccess'
 
+# 资源已经被操作过。
+FAILEDOPERATION_RESOURCEHADBEENDONE = 'FailedOperation.ResourceHadBeenDone'
+
 # 应用ID填写有误，请检查应用ID是否存在。
 FAILEDOPERATION_RESOURCENOTFOUND = 'FailedOperation.ResourceNotFound'
 
@@ -164,6 +167,12 @@ FAILEDOPERATION_RULEALREADYEXISTED = 'FailedOperation.RuleAlreadyExisted'
 # Session不存在或已经被取消。
 FAILEDOPERATION_SESSIONNOTEXIST = 'FailedOperation.SessionNotExist'
 
+# 标签资源绑定失败。
+FAILEDOPERATION_TAGRESOURCESFAILED = 'FailedOperation.TagResourcesFailed'
+
+# 标签资源解绑失败。
+FAILEDOPERATION_UNTAGRESOURCESFAILED = 'FailedOperation.UnTagResourcesFailed'
+
 # 用户未认证。
 FAILEDOPERATION_USERNOTAUTHENTICATED = 'FailedOperation.UserNotAuthenticated'
 
@@ -254,6 +263,9 @@ INVALIDPARAMETERVALUE_UNKNOWNDESTREGION = 'InvalidParameterValue.UnknownDestRegi
 # 超过配额限制。
 LIMITEXCEEDED = 'LimitExceeded'
 
+# 标签配额不足。
+LIMITEXCEEDED_TAGQUOTA = 'LimitExceeded.TagQuota'
+
 # 缺少参数错误。
 MISSINGPARAMETER = 'MissingParameter'
 
