@@ -26,6 +26,93 @@ class OceanusClient(AbstractClient):
     _service = 'oceanus'
 
 
+    def CheckSavepoint(self, request):
+        """检查快照是否可用
+
+        :param request: Request instance for CheckSavepoint.
+        :type request: :class:`tencentcloud.oceanus.v20190422.models.CheckSavepointRequest`
+        :rtype: :class:`tencentcloud.oceanus.v20190422.models.CheckSavepointResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CheckSavepoint", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CheckSavepointResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def CopyJobs(self, request):
+        """单条和批量复制作业
+
+        :param request: Request instance for CopyJobs.
+        :type request: :class:`tencentcloud.oceanus.v20190422.models.CopyJobsRequest`
+        :rtype: :class:`tencentcloud.oceanus.v20190422.models.CopyJobsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CopyJobs", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CopyJobsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def CreateFolder(self, request):
+        """作业列表页面新建文件夹请求
+
+        :param request: Request instance for CreateFolder.
+        :type request: :class:`tencentcloud.oceanus.v20190422.models.CreateFolderRequest`
+        :rtype: :class:`tencentcloud.oceanus.v20190422.models.CreateFolderResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateFolder", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateFolderResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateJob(self, request):
         """新建作业接口，一个 AppId 最多允许创建1000个作业
 
@@ -142,6 +229,35 @@ class OceanusClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteJobs(self, request):
+        """批量删除作业接口，批量操作数量上限20
+
+        :param request: Request instance for DeleteJobs.
+        :type request: :class:`tencentcloud.oceanus.v20190422.models.DeleteJobsRequest`
+        :rtype: :class:`tencentcloud.oceanus.v20190422.models.DeleteJobsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteJobs", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteJobsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteResourceConfigs(self, request):
         """删除资源版本
 
@@ -229,6 +345,35 @@ class OceanusClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeClusters(self, request):
+        """查询集群
+
+        :param request: Request instance for DescribeClusters.
+        :type request: :class:`tencentcloud.oceanus.v20190422.models.DescribeClustersRequest`
+        :rtype: :class:`tencentcloud.oceanus.v20190422.models.DescribeClustersResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeClusters", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeClustersResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeJobConfigs(self, request):
         """查询作业配置列表，一次最多查询100个
 
@@ -258,6 +403,35 @@ class OceanusClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeJobSavepoint(self, request):
+        """查找Savepoint列表
+
+        :param request: Request instance for DescribeJobSavepoint.
+        :type request: :class:`tencentcloud.oceanus.v20190422.models.DescribeJobSavepointRequest`
+        :rtype: :class:`tencentcloud.oceanus.v20190422.models.DescribeJobSavepointResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeJobSavepoint", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeJobSavepointResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeJobs(self, request):
         """查询作业
 
@@ -403,6 +577,73 @@ class OceanusClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeTreeJobs(self, request):
+        """生成树状作业显示结构
+
+        :param request: Request instance for DescribeTreeJobs.
+        :type request: :class:`tencentcloud.oceanus.v20190422.models.DescribeTreeJobsRequest`
+        :rtype: :class:`tencentcloud.oceanus.v20190422.models.DescribeTreeJobsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeTreeJobs", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeTreeJobsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def ModifyJob(self, request):
+        """更新作业属性，仅允许以下3种操作，不支持组合操作：
+        (1)	更新作业名称
+        (2)	更新作业备注
+        (3)	更新作业最大并行度
+        变更前提：WorkerCuNum<=MaxParallelism
+        如果MaxParallelism变小，不重启作业，待下一次重启生效
+        如果MaxParallelism变大，则要求入参RestartAllowed必须为True
+        假设作业运行状态，则先停止作业，再启动作业，中间状态丢失
+        假设作业暂停状态，则将作业更改为停止状态，中间状态丢失
+
+
+        :param request: Request instance for ModifyJob.
+        :type request: :class:`tencentcloud.oceanus.v20190422.models.ModifyJobRequest`
+        :rtype: :class:`tencentcloud.oceanus.v20190422.models.ModifyJobResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyJob", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyJobResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def RunJobs(self, request):
         """批量启动或者恢复作业，批量操作数量上限20
 
@@ -454,6 +695,35 @@ class OceanusClient(AbstractClient):
                 message = response["Response"]["Error"]["Message"]
                 reqid = response["Response"]["RequestId"]
                 raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def TriggerJobSavepoint(self, request):
+        """触发Savepoint
+
+        :param request: Request instance for TriggerJobSavepoint.
+        :type request: :class:`tencentcloud.oceanus.v20190422.models.TriggerJobSavepointRequest`
+        :rtype: :class:`tencentcloud.oceanus.v20190422.models.TriggerJobSavepointResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("TriggerJobSavepoint", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.TriggerJobSavepointResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
